summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codemethodblock.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/codemethodblock.h
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/codemethodblock.h')
-rw-r--r--umbrello/umbrello/codemethodblock.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/umbrello/umbrello/codemethodblock.h b/umbrello/umbrello/codemethodblock.h
index 41555627..a10a676c 100644
--- a/umbrello/umbrello/codemethodblock.h
+++ b/umbrello/umbrello/codemethodblock.h
@@ -35,6 +35,7 @@ class CodeMethodBlock : public CodeBlockWithComments, public OwnedCodeBlock
{
friend class CodeGenObjectWithTextBlocks;
Q_OBJECT
+ TQ_OBJECT
public:
// Constructors/Destructors
@@ -44,7 +45,7 @@ public:
/**
* Constructors
*/
- CodeMethodBlock ( ClassifierCodeDocument * doc, UMLObject * parentObj,
+ CodeMethodBlock ( ClassifierCodeDocument * doc, UMLObject * tqparentObj,
const TQString & body = "", const TQString & comment = "");
/**
@@ -56,7 +57,7 @@ public:
//
/**
- * @return QString
+ * @return TQString
*/
virtual TQString toString ( );
@@ -70,7 +71,7 @@ public:
*/
TQString getEndMethodText () const;
// get the parent code document
CodeDocument * getParentDocument();
protected:
@@ -92,13 +93,13 @@ protected:
*/
void setEndMethodText (const TQString &value);
- /** this is the method called from within syncToparent().
+ /** this is the method called from within syncTotqparent().
* to update the start and end Method text. It is called
* whether or not the method is Auto or User generated.
*/
virtual void updateMethodDeclaration ( ) = 0;
- /** this is the method called from within syncToparent().
+ /** this is the method called from within syncTotqparent().
* to update the *body* of the method
* It is only called if the method is Auto-generated.
*/
@@ -70,7 +71,7 @@ public:
*/
TQString getEndMethodText () const;
- // get the parent code document
+ // get the tqparent code document
CodeDocument * getParentDocument();
protected: